#!/usr/bin/bash

###############################################################
# VARIABLES
###############################################################
#==============================================================
# Database properties
#==============================================================
DB_HOSTNAME="HOSTNAME";
DB_USER="LOGIN";
DB_PASSWORD="PASSWORD";

#==============================================================
# Current Date Formats
#==============================================================
# Used in filenames
DATE=`date +%Y%m%d%H%M%S`;

# Used in emails
NOW=`date +%m/%d/%Y-%H:%M:%S`;

#==============================================================
# Type of backup (displayed on emailed report)
#==============================================================
JOB="Database Backup";

#==============================================================
# System programs
#==============================================================
GZIP="$(which gzip)";
MAIL="C:/cygwin/home/steved/bin/Email/do_email.php";
TAR="$(which tar)";
RM="$(which rm)";
MYSQLDUMP='/cygdrive/c/Program Files/MySQL/MySQL Server 5.1/bin/mysqldump';
CYGPATH="$(which cygpath)";

#==============================================================
# Name of computer backups are running on
#==============================================================
HOSTNAME="${HOSTNAME//\n/}"
SUBJECT_TYPE="Database";

#==============================================================
# List of email addresses to send report to
#==============================================================
EMAIL_TO="<person1@domain.com>";
EMAIL_CC="<person2@domain.com>";

#==============================================================
# Directory To Store Backup Files To
#==============================================================
BACKUP_DIR="/cygdrive/c/Storage/BACKUPS";
BACKUP_DIR_WINPATH="$(CYGPATH --mixed $BACKUP_DIR)";

#==============================================================
# Name of tarball that will contain all individual mysql dump files
#==============================================================
TARBALL_FILE=$DATE"_"$HOSTNAME"_backup_dbs.tar"
TARBALL=$BACKUP_DIR"/"$TARBALL_FILE
TARBALL_WINPATH=$BACKUP_DIR_WINPATH"/"$DATE"_"$HOSTNAME"_backup_dbs.tar"

#==============================================================
# Array of DB Names To Backup
#==============================================================
SOURCE_DBS=(db1 db2 db3);

###############################################################
# PROCESS EACH DB
###############################################################
if [ ! -d "$BACKUP_DIR" ]; then
    echo "Error: $BACKUP_DIR does not exists!";
    exit 1
fi
echo "Backing up to directory $BACKUP_DIR/ ..."
echo "";
for element in $(seq 0 $((${#SOURCE_DBS[@]} - 1)))
        do                
                #==============================================================
                # Backup DB
                #==============================================================
                source_db=${SOURCE_DBS[$element]};

                #==============================================================
                # Backup File Name / Path
                #==============================================================
                backup_file=$DATE"_"$HOSTNAME"_"$source_db".sql";
                backup_file_path=$BACKUP_DIR"/"$backup_file

                echo "Generating db backup file $backup_file.gz ..."

                #==============================================================
                # Execute mysqldump
                #==============================================================
                "$MYSQLDUMP" -u$DB_USER -p$DB_PASSWORD --opt $source_db > $backup_file_path

                #==============================================================
                # Compress the mysqldump file
                #==============================================================
                $GZIP $backup_file_path
                backup_list=$backup_list" "$backup_file".gz";
                backup_list_email=$backup_list_email"<br/>"$backup_file".gz";

done

#==============================================================
# Create the tarball that contains all of the mysqldump files
#==============================================================
cd $BACKUP_DIR
echo " ";
echo "Generating tarball backup file $TARBALL_FILE ..."
$TAR -cf $TARBALL $backup_list
$RM -f $backup_list

errors=0;
if [ "$errors" = 0 ]; then 
    STATUS="Complete";
    backup_message="<font style='font-family: Courier New'>$TARBALL_WINPATH</font><br/><br/>The backup file mentioned above c
ontains the following files:<br/><font style='font-family: Courier New'>$backup_list_email</font>";
else 
    STATUS="FAILED";
    backup_message="<br/>The backup failed for the following reason(s):<br/>";
fi

#==============================================================
# Email report
#==============================================================
$MAIL "$NOW" "$HOSTNAME" "$BACKUP_DIR_WINPATH" "$TARBALL_WINPATH" "$STATUS" "$backup_message" "$backup_list_email" "$EMAIL_TO
" "$EMAIL_CC" "$JOB" "$SUBJECT_TYPE"

exit 0
